#
# spec file for package python-dukpy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-dukpy
Version:        0.5.0
Release:        2.3
Summary:        JavaScript interpreter for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/amol-/dukpy
Source:         https://github.com/amol-/dukpy/archive/%{version}.tar.gz#/dukpy-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} >= 1699
BuildRequires:  %{python_module webassets}
Recommends:     python-webassets
%endif
%python_subpackages

%description
DukPy is a javascript interpreter for Python built on top of
duktape engine.
It comes with a bunch of common transpilers built-in for convenience:

    - CoffeeScript
    - BabelJS
    - TypeScript
    - JSX
    - LESS

%prep
%setup -q -n dukpy-%{version}
chmod a-x dukpy/jsmodules/react/react-dom-server.js
# remove test that relies on bunch of node binaries
rm tests/test_webassets_filter.py
# remove downloading tests
rm tests/test_installer.py
# https://github.com/amol-/dukpy/issues/60
sed -i 's:import mock:from unittest import mock:' tests/test_evaljs.py

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/dukpy
%python_clone -a %{buildroot}%{_bindir}/dukpy-install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch -v

%post
%python_install_alternative dukpy
%python_install_alternative dukpy-install

%postun
%python_uninstall_alternative dukpy
%python_uninstall_alternative dukpy-install

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/dukpy-install
%python_alternative %{_bindir}/dukpy
%{python_sitearch}/dukpy
%{python_sitearch}/dukpy-%{version}*-info

%changelog
* Tue Jan 21 2025 Markéta Machová <mmachova@suse.com>
- Avoid the webassets dependency on Leap 16
* Tue Nov 12 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.5.0
  * Upgrade duktape to 50af773
  * Testing and binary distribution for Python 3.13
- Update BuildRequires and Requires from setup.py
* Wed Jun 26 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.0
  * fix: prevent crash with unicode emoji
  * Switched to CESU-8 for encoding
- Update test/runtime requirements
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.3.1:
  * Python 3.12 officially supported
  * Emit the function name when Python callback fails
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
  - Use %%pytest_arch instead of custom command
  - More specific python_sitelib in %%files
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.3.0
  * Upgrade to duktape engine 2.7.0
  * Support for installing nodejs modules where the root distribution directory is not named package.
  * Better error message when a Python function is not found
  * GitHub Actions based release workflow, wheels are now automatically generated for more versions.
  * Wheels for Apple Silicon (M1) are now provided.
  * Support for Python 2.7, 3.5 and 3.6 is deprecated. DukPy might still work, but it's untested.
* Thu Apr 28 2022 pgajdos@suse.com
- do not require python-mock for build
* Tue Jul 13 2021 Jason Craig <os@jacraig.com>
- Update to 0.2.3
  * Support for Python 3.8
  * Testuite now based on pytest instead of nose
  * Deprecated support for Python 2.6 and 3.4
  * Updated included babel version to 6.26.0
- Drop pytest.patch, upstream has integrated those changes.
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.2:
  * State compatibility with Python 3.7
  * Provide wheels for Python 3.7
  * Fix building wheel from source distribution
  * Fix a memory leak in dukpy.evaljs
- Add patch from upstream to work well with pytest:
  * pytest.patch
* Thu Aug 16 2018 jengelh@inai.de
- Ensure neutrality of description.
* Tue Aug  7 2018 toddrme2178@gmail.com
- Initial version
